@@ -72,32 +72,6 @@ const char * const screenshot_types[] = {
 
 static char *bg_pictures_source_get_unique_filename (const char *uri);
 
-static void
-bg_pictures_source_get_property (GObject    *object,
-                                  guint       property_id,
-                                  GValue     *value,
-                                  GParamSpec *pspec)
-{
-  switch (property_id)
-    {
-    default:
-      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-    }
-}
-
-static void
-bg_pictures_source_set_property (GObject      *object,
-                                  guint         property_id,
-                                  const GValue *value,
-                                  GParamSpec   *pspec)
-{
-  switch (property_id)
-    {
-    default:
-      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-    }
-}
-
 static void
 bg_pictures_source_dispose (GObject *object)
 {
@@ -137,8 +111,6 @@ bg_pictures_source_class_init (BgPicturesSourceClass *klass)
 
   g_type_class_add_private (klass, sizeof (BgPicturesSourcePrivate));
 
-  object_class->get_property = bg_pictures_source_get_property;
-  object_class->set_property = bg_pictures_source_set_property;
   object_class->dispose = bg_pictures_source_dispose;
   object_class->finalize = bg_pictures_source_finalize;
 }
@@ -252,6 +224,8 @@ picture_opened_for_read (GObject *source_object,
   CcBackgroundItem *item;
   GFileInputStream *stream;
   GError *error = NULL;
+  gint thumbnail_height;
+  gint thumbnail_width;
 
   item = g_object_get_data (source_object, "item");
   stream = g_file_read_finish (G_FILE (source_object), res, &error);
@@ -274,9 +248,11 @@ picture_opened_for_read (GObject *source_object,
    */
   bg_source = BG_PICTURES_SOURCE (user_data);
 
+  thumbnail_height = bg_source_get_thumbnail_height (BG_SOURCE (bg_source));
+  thumbnail_width = bg_source_get_thumbnail_width (BG_SOURCE (bg_source));
   g_object_set_data_full (G_OBJECT (stream), "item", g_object_ref (item), g_object_unref);
   gdk_pixbuf_new_from_stream_at_scale_async (G_INPUT_STREAM (stream),
-                                             THUMBNAIL_WIDTH, THUMBNAIL_HEIGHT,
+                                             thumbnail_width, thumbnail_height,
                                              TRUE,
                                              bg_source->priv->cancellable,
                                              picture_scaled, bg_source);
@@ -942,9 +918,9 @@ bg_pictures_source_init (BgPicturesSource *self)
 }
 
 BgPicturesSource *
-bg_pictures_source_new (void)
+bg_pictures_source_new (GtkWindow *window)
 {
-  return g_object_new (BG_TYPE_PICTURES_SOURCE, NULL);
+  return g_object_new (BG_TYPE_PICTURES_SOURCE, "window", window, NULL);
 }
 
 const char * const *
