@@ -25,6 +25,7 @@
 
 #include <langinfo.h>
 #include <sys/time.h>
+#include "shell/list-box-helper.h"
 #include "cc-timezone-map.h"
 #include "timedated.h"
 #include "date-endian.h"
@@ -743,6 +744,26 @@ change_ntp (GObject         *gobject,
   queue_set_ntp (self);
 }
 
+static gboolean
+is_ntp_available (CcDateTimePanel *self)
+{
+  GVariant *value;
+  gboolean ntp_available = TRUE;
+
+  /* We need to access this directly so that we can default to TRUE if
+   * it is not set.
+   */
+  value = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (self->priv->dtm), "CanNTP");
+  if (value)
+    {
+      if (g_variant_is_of_type (value, G_VARIANT_TYPE_BOOLEAN))
+        ntp_available = g_variant_get_boolean (value);
+      g_variant_unref (value);
+    }
+
+  return ntp_available;
+}
+
 static void
 on_permission_changed (GPermission *permission,
                        GParamSpec  *pspec,
@@ -773,22 +794,7 @@ static void
 on_can_ntp_changed (CcDateTimePanel *self)
 {
   CcDateTimePanelPrivate *priv = self->priv;
-  gboolean ntp_available = TRUE;
-  GVariant *value;
-
-  /* We need to access this directly so that we can default to TRUE if
-   * it is not set.
-   */
-  value = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (self->priv->dtm), "CanNTP");
-  if (value)
-    {
-      if (g_variant_is_of_type (value, G_VARIANT_TYPE_BOOLEAN))
-        ntp_available = g_variant_get_boolean (value);
-      g_variant_unref (value);
-    }
-
-  gtk_widget_set_visible (W ("auto-datetime-row"),
-                          ntp_available);
+  gtk_widget_set_visible (W ("auto-datetime-row"), is_ntp_available (self));
 }
 
 static void
@@ -857,25 +863,6 @@ keynav_failed (GtkWidget        *listbox,
   return FALSE;
 }
 
-static void
-update_header (GtkListBoxRow *row,
-               GtkListBoxRow *before,
-               gpointer       user_data)
-{
-  GtkWidget *current;
-
-  if (before == NULL)
-    return;
-
-  current = gtk_list_box_row_get_header (row);
-  if (current == NULL)
-    {
-      current = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
-      gtk_widget_show (current);
-      gtk_list_box_row_set_header (row, current);
-    }
-}
-
 static void
 run_dialog (CcDateTimePanel *self,
             const gchar     *dialog_name)
@@ -971,7 +958,7 @@ setup_listbox (CcDateTimePanel *self,
 {
   CcDateTimePanelPrivate *priv = self->priv;
 
-  gtk_list_box_set_header_func (GTK_LIST_BOX (listbox), update_header, NULL, NULL);
+  gtk_list_box_set_header_func (GTK_LIST_BOX (listbox), cc_list_box_update_header_func, NULL, NULL);
   g_signal_connect (listbox, "row-activated",
                     G_CALLBACK (list_box_row_activated), self);
 
@@ -1281,6 +1268,8 @@ cc_date_time_panel_init (CcDateTimePanel *self)
   g_signal_connect (W("network_time_switch"), "notify::active",
                     G_CALLBACK (change_ntp), self);
 
+  gtk_widget_set_visible (W ("auto-datetime-row"), is_ntp_available (self));
+
   /* Timezone settings */
   bind_switch_to_row (self,
                       W ("auto_timezone_switch"),
