@@ -124,7 +124,7 @@ show_error_dialog (UmAccountDialog *self,
         GtkWidget *dialog;
 
         dialog = gtk_message_dialog_new (GTK_WINDOW (self),
-                                         GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                         GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_USE_HEADER_BAR,
                                          GTK_MESSAGE_ERROR,
                                          GTK_BUTTONS_CLOSE,
                                          "%s", message);
@@ -301,21 +301,14 @@ local_validate (UmAccountDialog *self)
         const gchar *password;
         const gchar *verify;
         gchar *tip;
-        gchar *hint;
         gint strength;
 
         name = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (self->local_username));
         valid_login = is_valid_username (name, &tip);
 
         entry = gtk_bin_get_child (GTK_BIN (self->local_username));
-        if (tip) {
-                hint = g_strdup_printf ("%s.", tip);
-                g_free (tip);
-        } else {
-                hint = g_strdup (_("This will be used to name your home folder and can't be changed."));
-        }
-        gtk_label_set_label (GTK_LABEL (self->local_username_hint), hint);
-        g_free (hint);
+        gtk_label_set_label (GTK_LABEL (self->local_username_hint), tip);
+        g_free (tip);
 
         if (valid_login) {
                 set_entry_validation_checkmark (GTK_ENTRY (entry));
@@ -1613,7 +1606,7 @@ um_account_dialog_class_init (UmAccountDialogClass *klass)
 UmAccountDialog *
 um_account_dialog_new (void)
 {
-        return g_object_new (UM_TYPE_ACCOUNT_DIALOG, NULL);
+        return g_object_new (UM_TYPE_ACCOUNT_DIALOG, "use-header-bar", TRUE, NULL);
 }
 
 void
