@@ -213,6 +213,7 @@ um_photo_dialog_select_file (UmPhotoDialog *um)
         GtkWidget *chooser;
         const gchar *folder;
         GtkWidget *preview;
+        GtkFileFilter *filter;
 
         chooser = gtk_file_chooser_dialog_new (_("Browse for more pictures"),
                                                GTK_WINDOW (gtk_widget_get_toplevel (um->popup_button)),
@@ -236,6 +237,10 @@ um_photo_dialog_select_file (UmPhotoDialog *um)
                 gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (chooser),
                                                      folder);
 
+        filter = gtk_file_filter_new ();
+        gtk_file_filter_add_pixbuf_formats (filter);
+        gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (chooser), filter);
+
         g_signal_connect (chooser, "response",
                           G_CALLBACK (file_chooser_response), um);
 
@@ -530,7 +535,7 @@ popup_button_draw (GtkWidget      *widget,
                    cairo_t        *cr,
                    UmPhotoDialog  *um)
 {
-        if (gtk_widget_get_state (gtk_bin_get_child (GTK_BIN (widget))) != GTK_STATE_PRELIGHT &&
+        if (!(gtk_widget_get_state_flags (gtk_bin_get_child (GTK_BIN (widget))) & GTK_STATE_FLAG_PRELIGHT) &&
             !gtk_widget_is_focus (widget)) {
                 return;
         }
